@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.13 2008/10/09 07:36:54 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.20 2009/03/04 11:47:40 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -40,36 +40,42 @@
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_destroy( GtkWidget *widget, gpointer user_data );
+gint handle_destroy( GtkWidget *widget, gpointer user_data );
 gint handle_expose( GtkWidget *widget, GdkEventExpose *event );
 
-void handle_ok_clicked(
+gint handle_ok_clicked(
 	GtkButton *button, gpointer user_data );
-void handle_cancel_clicked(
+gint handle_cancel_clicked(
 	GtkButton *button, gpointer user_data );
-void handle_next_chr_clicked(
+gint handle_next_chr_clicked(
 	GtkButton *button, gpointer user_data );
-void handle_prev_chr_clicked(
+gint handle_prev_chr_clicked(
 	GtkButton *button, gpointer user_data );
 
-void handle_stat_name_changed(
+gint handle_stat_name_changed(
 	GtkWidget *widget, GtkWidget *entry );
-void handle_stat_face_changed(
+gint handle_stat_face_changed(
 	GtkWidget *widget, GtkWidget *entry );
-void handle_stat_race_clicked(
+gint handle_stat_race_clicked(
 	GtkButton *button, gpointer user_data );
-void handle_stat_race_name_changed(
+gint handle_stat_race_name_changed(
 	GtkWidget *widget, GtkWidget *entry );
-void handle_stat_sex_clicked(
+gint handle_stat_sex_clicked(
 	GtkButton *button, gpointer user_data );
-void handle_stat_tile_clicked(
+gint handle_stat_tile_clicked(
 	GtkButton *button, gpointer user_data );
-void handle_abl_class_clicked(
+
+gint handle_abl_class_clicked(
+	GtkButton *button, gpointer user_data );
+
+gint handle_skill_class_clicked(
+	GtkButton *button, gpointer user_data );
+gint handle_skill_name_clicked(
 	GtkButton *button, gpointer user_data );
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
-// 쥦ɥ饯ȡɥΥ󥹥ȥ饯
+// 饯ȡɥΥ󥹥ȥ饯
 ////////////////////////////////////////////////////////////////
 
 GuiChrSheet::GuiChrSheet()
@@ -113,6 +119,8 @@ void GuiChrSheet::newWin()
 	newWinMisc();
 	newWinStatTab();
 	newWinAblTab();
+	for( long i = 0; i < SKILL_MAX_PAGE; i++ )
+		newWinSkillTab( i );
 	newWinItemTab();
 	newWinEquipTab();
 #endif	// D_GTK
@@ -1184,6 +1192,8 @@ void GuiChrSheet::newWinAblTab()
 	gtk_widget_show( label );
 	x++;
 
+	// ٥ν
+
 	x++;
 
 	// и
@@ -1203,6 +1213,8 @@ void GuiChrSheet::newWinAblTab()
 	gtk_widget_show( label );
 	x++;
 
+	// ڤ
+
 	x++;
 
 	// ɬ׷и
@@ -1537,6 +1549,300 @@ void GuiChrSheet::newWinAblTab()
 #endif	// D_GTK
 }
 
+////////////////////////////////////////////////////////////////
+// 롦֤κ
+////////////////////////////////////////////////////////////////
+
+void GuiChrSheet::newWinSkillTab( long page )
+{
+#ifdef D_GTK
+	GtkWidget *label;
+	long xn, yn;
+	GtkWidget *pTab;
+	long x, y;
+	GtkAttachOptions xOpt, yOpt;
+	static char str[SCREEN_WIDTH + 1];
+
+	// ֤Υ٥
+
+	if( page == 0 )
+		label = gtk_label_new( MSG_SKILL_A );
+	else
+		label = gtk_label_new( MSG_SKILL_B );
+	if( label == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+		return;
+	}
+	gtk_widget_show( label );
+
+	// ܥåκ
+
+	GtkWidget *vBox = gtk_vbox_new( FALSE, 0 );
+	if( vBox == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_vbox_new()" );
+		return;
+	}
+	gtk_notebook_append_page( GTK_NOTEBOOK( mNoteBook ),
+			vBox, label );
+	gtk_widget_show( vBox );
+
+	// 饹
+
+	sn_printf( str, CLASS_NAME_MAX_LEN, "%*s",
+			CLASS_NAME_MAX_LEN, " " );
+	mSkillClass = gtk_button_new_with_label( str );
+	if( mSkillClass == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
+		return;
+	}
+	gtk_signal_connect( GTK_OBJECT( mSkillClass ),
+			"clicked",
+			GTK_SIGNAL_FUNC( handle_skill_class_clicked ),
+			this );
+	gtk_box_pack_start( GTK_BOX( vBox ), mSkillClass, TRUE, TRUE, 0 );
+	gtk_widget_show( mSkillClass );
+
+	// ơ֥κ
+
+	xn = 5;
+	yn = 1 + SKILL_PER_PAGE_MAX_N;
+	pTab = gtk_table_new( xn, yn, FALSE );
+	if( pTab == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_table_new()" );
+		return;
+	}
+	gtk_box_pack_start( GTK_BOX( vBox ), pTab, TRUE, TRUE, 0 );
+	gtk_widget_show( pTab );
+
+	x = 0;
+	y = 0;
+
+	// ̾
+
+	if( page == 0 )
+		label = gtk_label_new( MSG_MBR_DATA_SKILL_NAME_A_TTL );
+	else
+		label = gtk_label_new( MSG_MBR_DATA_SKILL_NAME_B_TTL );
+	if( label == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+		return;
+	}
+	gtk_misc_set_alignment( GTK_MISC( label ), 0.0, 0.5 );
+	xOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	yOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	gtk_table_attach( GTK_TABLE( pTab ), label,
+		x, x + 1, y, y + 1,
+		xOpt, yOpt,
+		4, 0 );
+	gtk_widget_show( label );
+	x++;
+
+	// ٥
+
+	label = gtk_label_new( MSG_MBR_DATA_SKILL_LEV_TTL );
+	if( label == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+		return;
+	}
+	gtk_misc_set_alignment( GTK_MISC( label ), 1.0, 0.5 );
+	xOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	yOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	gtk_table_attach( GTK_TABLE( pTab ), label,
+		x, x + 1, y, y + 1,
+		xOpt, yOpt,
+		4, 0 );
+	gtk_widget_show( label );
+	x++;
+
+	// и
+
+	label = gtk_label_new( MSG_MBR_DATA_SKILL_EXP_TTL );
+	if( label == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+		return;
+	}
+	gtk_misc_set_alignment( GTK_MISC( label ), 1.0, 0.5 );
+	xOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	yOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	gtk_table_attach( GTK_TABLE( pTab ), label,
+		x, x + 1, y, y + 1,
+		xOpt, yOpt,
+		4, 0 );
+	gtk_widget_show( label );
+	x++;
+
+	// ڤ
+
+	x++;
+
+	// ɬ׷и
+
+	label = gtk_label_new( MSG_MBR_DATA_SKILL_NEED_EXP_TTL );
+	if( label == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+		return;
+	}
+	gtk_misc_set_alignment( GTK_MISC( label ), 1.0, 0.5 );
+	xOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	yOpt = (GtkAttachOptions)(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+	gtk_table_attach( GTK_TABLE( pTab ), label,
+		x, x + 1, y, y + 1,
+		xOpt, yOpt,
+		4, 0 );
+	gtk_widget_show( label );
+	x++;
+
+	// ǽ
+
+	x = 0;
+	y = 0;
+	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
+		x = 0;
+		y = 1 + i;
+
+		// ̾
+
+		long nSlot = page * SKILL_PER_PAGE_MAX_N + i;
+
+		sn_printf( str, SCREEN_WIDTH, "%*s",
+				SKILL_NAME_MAX_LEN, " " );
+		mSkillName[page][i] = gtk_button_new_with_label( str );
+		if( mSkillName[page][i] == NULL ){
+			print_msg( FLG_MSG_ERR,
+					"gtk_button_new_with_label()" );
+			return;
+		}
+		gtk_signal_connect( GTK_OBJECT( mSkillName[page][i] ),
+				"clicked",
+				GTK_SIGNAL_FUNC( handle_skill_name_clicked ),
+				(gpointer)nSlot );
+		xOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		yOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		gtk_table_attach( GTK_TABLE( pTab ), mSkillName[page][i],
+			x, x + 1, y, y + 1,
+			xOpt, yOpt,
+			4, 0 );
+		gtk_widget_show( mSkillName[page][i] );
+		x++;
+
+		// ٥
+
+		sn_printf( str, SCREEN_WIDTH, "%4s", " " );
+		mSkillLev[page][i] = gtk_label_new( str );
+		if( mSkillLev[page][i] == NULL ){
+			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+			return;
+		}
+		gtk_misc_set_alignment( GTK_MISC( mSkillLev[page][i] ),
+				1.0, 0.5 );
+		xOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		yOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		gtk_table_attach( GTK_TABLE( pTab ), mSkillLev[page][i],
+			x, x + 1, y, y + 1,
+			xOpt, yOpt,
+			4, 0 );
+		gtk_widget_show( mSkillLev[page][i] );
+		x++;
+
+		// и
+
+		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		mSkillExp[page][i] = gtk_label_new( str );
+		if( mSkillExp[page][i] == NULL ){
+			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+			return;
+		}
+		gtk_misc_set_alignment( GTK_MISC( mSkillExp[page][i] ),
+				1.0, 0.5 );
+		xOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		yOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		gtk_table_attach( GTK_TABLE( pTab ), mSkillExp[page][i],
+			x, x + 1, y, y + 1,
+			xOpt, yOpt,
+			4, 0 );
+		gtk_widget_show( mSkillExp[page][i] );
+		x++;
+
+		// ڤ
+
+		label = gtk_label_new( "/" );
+		if( label == NULL ){
+			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+			return;
+		}
+		gtk_misc_set_alignment( GTK_MISC( label ),
+				1.0, 0.5 );
+		xOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		yOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		gtk_table_attach( GTK_TABLE( pTab ), label,
+			x, x + 1, y, y + 1,
+			xOpt, yOpt,
+			4, 0 );
+		gtk_widget_show( label );
+		x++;
+
+		// ɬ׷и
+
+		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		mSkillNeedExp[page][i] = gtk_label_new( str );
+		if( mSkillNeedExp[page][i] == NULL ){
+			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
+			return;
+		}
+		gtk_misc_set_alignment( GTK_MISC( mSkillNeedExp[page][i] ),
+				1.0, 0.5 );
+		xOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		yOpt = (GtkAttachOptions)
+				(GTK_EXPAND | GTK_SHRINK | GTK_FILL);
+		gtk_table_attach( GTK_TABLE( pTab ), mSkillNeedExp[page][i],
+			x, x + 1, y, y + 1,
+			xOpt, yOpt,
+			4, 0 );
+		gtk_widget_show( mSkillNeedExp[page][i] );
+		x++;
+
+		y++;
+	}
+
+	// ҥȤΥ롦ɥ
+
+	mSkillTextScroll[page] = gtk_scrolled_window_new( NULL, NULL );
+	if( mSkillTextScroll[page] == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_scrolled_window_new()" );
+		return;
+	}
+	gtk_scrolled_window_set_policy(
+			GTK_SCROLLED_WINDOW( mSkillTextScroll[page] ),
+			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
+	gtk_scrolled_window_set_shadow_type(
+			GTK_SCROLLED_WINDOW( mSkillTextScroll[page] ),
+			GTK_SHADOW_IN );
+	gtk_box_pack_start( GTK_BOX( vBox ), mSkillTextScroll[page],
+			TRUE, TRUE, 0 );
+	gtk_widget_show( mSkillTextScroll[page] );
+
+	// ҥȤΥӥ塼
+
+	mSkillTextView[page] = gtk_text_view_new();
+	if( mSkillTextView[page] == NULL ){
+		print_msg( FLG_MSG_ERR, "gtk_text_view_new()" );
+		return;
+	}
+	gtk_widget_show( mSkillTextView[page] );
+	gtk_container_add( GTK_CONTAINER( mSkillTextScroll[page] ),
+			mSkillTextView[page] );
+#endif	// D_GTK
+}
+
 ////////////////////////////////////////////////////////////////
 // ƥࡦ֤κ
 ////////////////////////////////////////////////////////////////
@@ -1748,7 +2054,8 @@ void GuiChrSheet::destroy()
 
 ////////////////////////////////////////////////////////////////
 // 饯ȡɥɽ
-// chr_t *p : 饯
+// mbr_t *org : 饯θǡ
+// mbr_t *mbr : 饯
 ////////////////////////////////////////////////////////////////
 
 void GuiChrSheet::draw( mbr_t *org, mbr_t *mbr )
@@ -1793,6 +2100,8 @@ void GuiChrSheet::redraw()
 	drawMisc( orgData, mbrData );
 	drawStat( orgData, mbrData );
 	drawAbl( orgData, mbrData );
+	for( long i = 0; i < SKILL_MAX_PAGE; i++ )
+		drawSkill( orgData, mbrData, i );
 	drawItem( orgData, mbrData );
 	drawEquip( orgData, mbrData );
 
@@ -2147,6 +2456,63 @@ void GuiChrSheet::DdxToSheet()
 		mChrSheetWin->m_Abl.m_StrResi[i] = s;
 	}
 
+	////  A
+
+	class_t *tab = get_class_tab();
+	mChrSheetWin->m_SkillA.m_pClassTab = &(tab[mbrData->class_n]);
+	mChrSheetWin->m_SkillA.m_nSkillHead = SKILL_PER_PAGE_MAX_N * 0;
+	mChrSheetWin->m_SkillA.m_StrName = mbrData->name;
+	mChrSheetWin->m_SkillA.m_StrClass = tab[mbrData->class_n].name;
+
+	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
+		long nSlot = (SKILL_PER_PAGE_MAX_N * 0) + i;
+		long nLev = get_skill_lev_from_slot( mbrData, nSlot );
+		long nExp = get_skill_exp_from_slot( mbrData, nSlot );
+		long nNeedExp = get_skill_need_exp_from_slot( mbrData, nSlot );
+
+		char s[32 + 1];
+
+		mChrSheetWin->m_SkillA.m_StrKind[i]
+				= get_skill_name_from_slot( mbrData, nSlot );
+
+		sn_printf( s, 32, "%4ld", nLev );
+		mChrSheetWin->m_SkillA.m_StrLev[i] = s;
+
+		sn_printf( s, 32, "%4ld", nExp );
+		mChrSheetWin->m_SkillA.m_StrExp[i] = s;
+
+		sn_printf( s, 32, "%4ld", nNeedExp );
+		mChrSheetWin->m_SkillA.m_StrNeedExp[i] = s;
+	}
+
+	////  B
+
+	mChrSheetWin->m_SkillB.m_pClassTab = &(tab[mbrData->class_n]);
+	mChrSheetWin->m_SkillB.m_nSkillHead = SKILL_PER_PAGE_MAX_N * 1;
+	mChrSheetWin->m_SkillB.m_StrName = mbrData->name;
+	mChrSheetWin->m_SkillB.m_StrClass = tab[mbrData->class_n].name;
+
+	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
+		long nSlot = (SKILL_PER_PAGE_MAX_N * 1) + i;
+		long nLev = get_skill_lev_from_slot( mbrData, nSlot );
+		long nExp = get_skill_exp_from_slot( mbrData, nSlot );
+		long nNeedExp = get_skill_need_exp_from_slot( mbrData, nSlot );
+
+		char s[32 + 1];
+
+		mChrSheetWin->m_SkillB.m_StrKind[i]
+				= get_skill_name_from_slot( mbrData, nSlot );
+
+		sn_printf( s, 32, "%4ld", nLev );
+		mChrSheetWin->m_SkillB.m_StrLev[i] = s;
+
+		sn_printf( s, 32, "%4ld", nExp );
+		mChrSheetWin->m_SkillB.m_StrExp[i] = s;
+
+		sn_printf( s, 32, "%4ld", nNeedExp );
+		mChrSheetWin->m_SkillB.m_StrNeedExp[i] = s;
+	}
+
 	// ƥ
 
 	mChrSheetWin->m_Item.m_StrName = mbrData->name;
@@ -2764,6 +3130,121 @@ void GuiChrSheet::drawAbl( mbr_t *org, mbr_t *mbr )
 #endif // D_GTK
 }
 
+////////////////////////////////////////////////////////////////
+// 롦֤ɽ
+// mbr_t *org : ꥸʥΥС
+// mbr_t *mbr : ԽΥС
+// long page : ڡ
+////////////////////////////////////////////////////////////////
+
+void GuiChrSheet::drawSkill( mbr_t *org, mbr_t *mbr, long page )
+{
+	if( org == NULL )
+		return;
+	if( mbr == NULL )
+		return;
+
+#ifdef D_GTK
+	class_t *class_tab = get_class_tab();
+	if( class_tab == NULL )
+		return;
+
+	set_label_text_button(
+			GTK_BUTTON( mSkillClass ),
+			class_tab[mbr->class_n].name,
+			0.5, 0.5 );
+
+	for( long i = 0; i < SKILL_PER_PAGE_MAX_N; i++ ){
+		long nSlot = page * SKILL_PER_PAGE_MAX_N + i;
+
+		skill_kind_t skill_kind
+				= class_tab[mbr->class_n].skill[nSlot];
+		abl_kind_t abl_kind = (abl_kind_t)
+				(ABL_KIND_MAX_N + skill_kind);
+		long mbr_lev = 0;
+		long mbr_exp = 0;
+		long mbr_need_exp = 0;
+		if( skill_kind != SKILL_KIND_NULL ){
+			mbr_lev = get_lev( mbr, abl_kind );
+			mbr_exp = mbr->abl.exp[abl_kind].n;
+			mbr_need_exp = calc_need_exp( mbr_lev + 1,
+					abl_kind );
+		}
+		static char str[SCREEN_WIDTH + 1];
+
+		// ̾
+
+		sn_printf( str, SCREEN_WIDTH, "%s",
+				get_skill_name_from_kind( skill_kind ) );
+		set_label_text_button(
+				GTK_BUTTON( mSkillName[page][i] ),
+				str, 0.0, 0.5 );
+
+		// ٥
+
+		sn_printf( str, SCREEN_WIDTH, "%ld",
+				mbr_lev );
+		gtk_label_set_text( GTK_LABEL( mSkillLev[page][i] ),
+				str );
+
+		// и
+
+		sn_printf( str, SCREEN_WIDTH, "%ld",
+				mbr_exp );
+		gtk_label_set_text( GTK_LABEL( mSkillExp[page][i] ),
+				str );
+
+		// ɬ׷и
+
+		sn_printf( str, SCREEN_WIDTH, "%ld",
+				mbr_need_exp );
+		gtk_label_set_text( GTK_LABEL( mSkillNeedExp[page][i] ),
+				str );
+	}
+#endif // D_GTK
+}
+
+////////////////////////////////////////////////////////////////
+// ΥҥȤɽ
+// long nSlot : Υåֹ
+////////////////////////////////////////////////////////////////
+
+void GuiChrSheet::drawSkillHint( long nSlot )
+{
+	if( mbrData == NULL )
+		return;
+
+	class_t *class_tab = get_class_tab();
+	if( class_tab == NULL )
+		return;
+
+#ifdef D_GTK
+	long page = nSlot / SKILL_PER_PAGE_MAX_N;
+	GtkTextBuffer *buf = gtk_text_view_get_buffer(
+			GTK_TEXT_VIEW( mSkillTextView[page] ) );
+
+	// ŤƥȤ
+
+	GtkTextIter cur, bgn, end;
+	gtk_text_buffer_get_start_iter( buf, &bgn );
+	gtk_text_buffer_get_end_iter( buf, &end );
+	gtk_text_buffer_delete( buf, &bgn, &end );
+
+	// ƥȤɲ
+
+	skill_kind_t skill_kind = class_tab[mbrData->class_n].skill[nSlot];
+	if( skill_kind == SKILL_KIND_NULL )
+		return;
+
+	const char *hint = get_skill_hint( skill_kind );
+	if( hint == NULL )
+		return;
+
+	gtk_text_buffer_get_end_iter( buf, &cur );
+	gtk_text_buffer_insert( buf, &cur, hint, str_len_std( hint ) );
+#endif // D_GTK
+}
+
 ////////////////////////////////////////////////////////////////
 // ƥࡦ֤ɽ
 // mbr_t *org : ꥸʥΥС
@@ -3020,6 +3501,25 @@ bool GuiChrSheet::classClicked()
 	return true;
 }
 
+////////////////////////////////////////////////////////////////
+// 롦ܥΥåν
+// long n : Υåֹ
+// return : Ǥ?
+////////////////////////////////////////////////////////////////
+
+bool GuiChrSheet::skillClicked( long n )
+{
+	drawSkillHint( n );
+
+	data_n_t data = (data_n_t)(DATA_N_SKILL_A_00 + n);
+
+	DdxFromSheet();
+
+	set_data_n( data );
+	gKey.setChar( '\n' );
+	return true;
+}
+
 ////////////////////////////////////////////////////////////////
 // ƥࡦܥΥåν
 // long n : ƥֹ
@@ -3063,9 +3563,11 @@ bool GuiChrSheet::equipClicked( long n )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_destroy( GtkWidget *widget, gpointer user_data )
+gint handle_destroy( GtkWidget *widget, gpointer user_data )
 {
 	gGuiChrSheet.destroy();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3081,7 +3583,7 @@ gint handle_expose( GtkWidget *widget, GdkEventExpose *event )
 {
 	gGuiChrSheet.redraw();
 
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -3092,11 +3594,13 @@ gint handle_expose( GtkWidget *widget, GdkEventExpose *event )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_ok_clicked(
+gint handle_ok_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.okClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3107,11 +3611,13 @@ void handle_ok_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_cancel_clicked(
+gint handle_cancel_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.cancelClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3122,11 +3628,13 @@ void handle_cancel_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_next_chr_clicked(
+gint handle_next_chr_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.nextChrClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3137,11 +3645,13 @@ void handle_next_chr_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_prev_chr_clicked(
+gint handle_prev_chr_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.prevChrClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3152,11 +3662,13 @@ void handle_prev_chr_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_name_changed(
+gint handle_stat_name_changed(
 	GtkWidget *widget, GtkWidget *entry
 )
 {
 	gGuiChrSheet.nameChanged();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3167,11 +3679,13 @@ void handle_stat_name_changed(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_face_changed(
+gint handle_stat_face_changed(
 	GtkWidget *widget, GtkWidget *entry
 )
 {
 	gGuiChrSheet.faceChanged();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3182,11 +3696,13 @@ void handle_stat_face_changed(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_race_clicked(
+gint handle_stat_race_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.raceClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3197,11 +3713,13 @@ void handle_stat_race_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_race_name_changed(
+gint handle_stat_race_name_changed(
 	GtkWidget *widget, GtkWidget *entry
 )
 {
 	gGuiChrSheet.raceNameChanged();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3212,11 +3730,13 @@ void handle_stat_race_name_changed(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_sex_clicked(
+gint handle_stat_sex_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.sexClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3227,11 +3747,13 @@ void handle_stat_sex_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_tile_clicked(
+gint handle_stat_tile_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.tileClicked();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -3242,10 +3764,46 @@ void handle_stat_tile_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_abl_class_clicked(
+gint handle_abl_class_clicked(
 	GtkButton *button, gpointer user_data
 )
 {
 	gGuiChrSheet.classClicked();
+
+	return 0;
+}
+#endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// 롦֤Υ饹ܥΥåΥϥɥ
+// GtkButton *button : ܥ
+// gpointer user_data : ܥμ
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_skill_class_clicked(
+	GtkButton *button, gpointer user_data
+)
+{
+	gGuiChrSheet.classClicked();
+
+	return 0;
+}
+#endif // D_GTK
+
+////////////////////////////////////////////////////////////////
+// 롦ܥΥåΥϥɥ
+// GtkButton *button : ܥ
+// gpointer user_data : ܥμ
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_skill_name_clicked(
+	GtkButton *button, gpointer user_data
+)
+{
+	gGuiChrSheet.skillClicked( (long)user_data );
+
+	return 0;
 }
 #endif // D_GTK
