@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.20 2008/09/21 22:58:48 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.24 2009/03/04 11:47:40 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -47,10 +47,10 @@
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_win_delete(
+gint handle_stat_win_delete(
 	GtkWidget *widget, gpointer data
 );
-void handle_stat_win_destroy(
+gint handle_stat_win_destroy(
 	GtkWidget *widget, gpointer data
 );
 gint handle_stat_win_expose(
@@ -60,10 +60,10 @@ gint handle_stat_win_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 );
 
-void handle_stat_name_clicked(
+gint handle_stat_name_clicked(
 	GtkWidget *widget, gpointer data
 );
-void handle_stat_stat_clicked(
+gint handle_stat_stat_clicked(
 	GtkWidget *widget, gpointer data
 );
 #endif // D_GTK
@@ -914,11 +914,13 @@ WSCstring GuiStat::getStatStr( mbr_t *mbr )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_win_delete(
+gint handle_stat_win_delete(
 	GtkWidget *widget, gpointer data
 )
 {
 	gWinPos[WIN_KIND_STAT].wipe( WIN_KIND_STAT );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -929,14 +931,16 @@ void handle_stat_win_delete(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_win_destroy(
+gint handle_stat_win_destroy(
 	GtkWidget *widget, gpointer data
 )
 {
 	if( data == NULL )
-		return;
+		return 0;
 
 	((GuiStat *)data)->destroy();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -954,7 +958,7 @@ gint handle_stat_win_expose(
 {
 	gGuiStat.redraw( true );
 
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -970,7 +974,7 @@ gint handle_stat_win_configure(
 	GtkWidget *widget, GdkEventConfigure *event
 )
 {
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -981,7 +985,7 @@ gint handle_stat_win_configure(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_name_clicked(
+gint handle_stat_name_clicked(
 	GtkWidget *widget, gpointer data
 )
 {
@@ -994,7 +998,7 @@ void handle_stat_name_clicked(
 	WSCstring sCmd = "";
 
 	// ˥塼򳫤ƤĤ
-	sCmd = "00000000000000000000000000000000";
+	sCmd = "00000000000000000000";
 
 	// Сΰ֤˥ư
 	sCmd += ":/misc/cursor/cursor/move member\n";
@@ -1004,8 +1008,10 @@ void handle_stat_name_clicked(
 	sCmd += "^M";
 
 	// ޥɤ
-	set_key_buf_str( sCmd );
+	set_key_buf_str_tail( sCmd );
 	set_flg_break_key( TRUE );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -1016,7 +1022,7 @@ void handle_stat_name_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_stat_stat_clicked(
+gint handle_stat_stat_clicked(
 	GtkWidget *widget, gpointer data
 )
 {
@@ -1029,7 +1035,7 @@ void handle_stat_stat_clicked(
 	WSCstring sCmd = "";
 
 	// ˥塼򳫤ƤĤ
-	sCmd = "00000000000000000000000000000000";
+	sCmd = "00000000000000000000";
 
 	// Сΰ֤˥ư
 	sCmd += ":/misc/cursor/cursor/move member\n";
@@ -1040,7 +1046,9 @@ void handle_stat_stat_clicked(
 	sCmd += "C";
 
 	// ޥɤ
-	set_key_buf_str( sCmd );
+	set_key_buf_str_tail( sCmd );
 	set_flg_break_key( TRUE );
+
+	return 0;
 }
 #endif // D_GTK
