@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiWords.cpp,v 1.4 2008/09/02 06:23:44 bowkenken Exp $
+* $Id: GuiWords.cpp,v 1.7 2009/03/04 11:47:40 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -40,10 +40,10 @@
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_words_destroy( GtkWidget *widget, gpointer user_data );
+gint handle_words_destroy( GtkWidget *widget, gpointer user_data );
 gint handle_words_expose( GtkWidget *widget, GdkEventExpose *event );
 
-void handle_words_ok_clicked( GtkButton *button, gpointer user_data );
+gint handle_words_ok_clicked( GtkButton *button, gpointer user_data );
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -227,7 +227,7 @@ void GuiWords::draw( const char *str, long w )
 
 	const char *head, *tail;
 	for( head = str; ; head = tail ){
-		static char line[SCREEN_WIDTH * 2 + 1];
+		static char line[SCREEN_WIDTH * 4 + 1];
 
 		tail = get_words_line( head, w );
 		if( tail == NULL )
@@ -253,7 +253,7 @@ void GuiWords::draw( const char *str, long w )
 
 	head = str;
 	for( long i = 0; i < LOOP_MAX_1000; i++ ){
-		static char line[SCREEN_WIDTH * 2 + 1];
+		static char line[SCREEN_WIDTH * 4 + 1];
 
 		tail = get_words_line( head, w );
 		if( tail == NULL )
@@ -327,9 +327,11 @@ void GuiWords::okClicked()
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_words_destroy( GtkWidget *widget, gpointer user_data )
+gint handle_words_destroy( GtkWidget *widget, gpointer user_data )
 {
 	gGuiWords.destroy();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -345,7 +347,7 @@ gint handle_words_expose( GtkWidget *widget, GdkEventExpose *event )
 {
 	gGuiWords.redraw();
 
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -356,8 +358,10 @@ gint handle_words_expose( GtkWidget *widget, GdkEventExpose *event )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_words_ok_clicked( GtkButton *button, gpointer user_data )
+gint handle_words_ok_clicked( GtkButton *button, gpointer user_data )
 {
 	gGuiWords.okClicked();
+
+	return 0;
 }
 #endif // D_GTK
