@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDun.h,v 1.61 2008/10/05 20:09:27 bowkenken Exp $
+* $Id: PcgDun.h,v 1.68 2009/01/15 10:11:17 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_H
@@ -47,6 +47,7 @@
 #include "DemoLastBoss.h"
 #include "DemoGameOver.h"
 #include "DemoEnding.h"
+#include "GuiLastBoss.h"
 #include "Pcg.h"
 
 #ifdef D_WS
@@ -142,18 +143,22 @@ private:
 	Pcg pcgFloorTown;
 	Pcg pcgFloorDun;
 	Pcg pcgFloorLast;
-	// 
+	// ΥѥΥꥹ
 	Pcg pcgHole;
 	// ɤΥѥΥꥹ
 	Pcg pcgWallTown;
 	Pcg pcgWallDun;
 	Pcg pcgWallLast;
 	Pcg pcgStatue;
+	Pcg pcgBootUnit;
 	// ΥѥΥꥹ
 	Pcg pcgStreetlampOn;
 	Pcg pcgStreetlampOff;
 	// ĤΥѥΥꥹ
 	Pcg pcgSignboard;
+	// ΥѥΥꥹ
+	// ϴΥѥΥꥹ
+	Pcg pcgLava;
 	// ʤΥѥΥꥹ
 	Pcg pcgStairsUpTown;
 	Pcg pcgStairsUpDun;
@@ -185,6 +190,9 @@ private:
 	// 󥹥ΥѥΥꥹ
 	Pcg *aPcgMnstr[MNSTR_KIND_MAX_N];
 
+	// 饹ܥ
+	GuiLastBoss lastBossXX;
+
 	// ѥΥХꥨμΥޥå
 	rate_t rateMap[MAP_MAX_Y][MAP_MAX_X];
 
@@ -193,6 +201,9 @@ private:
 	WallPtnType nWallPtnTypeDun;
 	WallPtnType nWallPtnTypeLast;
 
+	// Υ˥ᡦե졼
+	long nWaterAnimeN;
+
 	// 褹ɬפ륭饯Υޥå
 	bool bFlgUpdate[MAP_MAX_Y][MAP_MAX_X];
 
@@ -242,18 +253,29 @@ private:
 #ifdef D_GTK
 	// եȤΥ
 	GtkStyle *pStyle;
+	GtkStyle *pStyleVfx;
 
 	// եȤΥ
 	gint nLeftBearing, nRightBearing;
 	gint nWidth, nAscent, nDescent;
+	gint nLeftBearingVfx, nRightBearingVfx;
+	gint nWidthVfx, nAscentVfx, nDescentVfx;
 #endif // D_GTK
 
 #ifdef D_MFC
 	// եȤΥ
 	void *pStyle;
+	void *pStyleVfx;
+
 	LOGFONT mTextFontDesc;
 	CFont *pTextFont;
 	CClientDC *pDc;
+
+	LOGFONT mTextFontDescVfx;
+	CFont *pTextFontVfx;
+	CClientDC *pDcVfx;
+
+	CDir3dText mD3Vfx;
 #endif // D_MFC
 
 	// ˥ޥåפ褹뤫?
@@ -306,6 +328,11 @@ public:
 	void drawTurn( bool flgForce = false );
 	void flush( long mapX, long mapY, long mapW, long mapH );
 	bool drawString( long scrn_x, long scrn_y, const char *s, ... );
+	bool drawVfx(
+		long scrn_x, long scrn_y,
+		long scrn_w, long scrn_h,
+		bool flgForce );
+	void setXxAttack( xx_act_kind_t kind, void *p );
 
 	void setFlgUpdateRequest( bool flg );
 
@@ -405,6 +432,14 @@ private:
 	bool drawText( long mapX, long mapY, long mapW, long mapH );
 /*
 	bool drawString( long scrn_x, long scrn_y, const char *s, ... );
+*/
+	void initVfx();
+/*
+	bool drawVfx(
+		long scrn_x, long scrn_y,
+		long scrn_w, long scrn_h,
+		bool flgForce );
+	void setXxAttack( xx_act_kind_t kind, void *p );
 */
 #ifdef D_GTK
 	bool user_select_font( GdkFont **font );
@@ -453,8 +488,10 @@ private:
 		bool flagHalfX, bool flagHalfY
 	);
 	bool drawStatue( long mapX, long mapY );
+	bool drawBootUnit( long mapX, long mapY );
 	bool drawStreetlamp( long mapX, long mapY );
 	bool drawSignboard( long mapX, long mapY );
+	bool drawWater( long mapX, long mapY );
 	bool drawStairsUp( long mapX, long mapY );
 	bool drawStairsDown( long mapX, long mapY );
 	bool drawDoorClose( long mapX, long mapY );
@@ -503,6 +540,7 @@ private:
 */
 	bool chkDrawWall( long mapX, long mapY );
 	bool chkDrawStatue( long mapX, long mapY );
+	bool chkDrawBootUnit( long mapX, long mapY );
 	bool chkDrawStreetlamp( long mapX, long mapY );
 	bool chkDrawSignboard( long mapX, long mapY );
 	bool chkDrawSanctuary( long mapX, long mapY, trap_t *trap );
