@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: WinPos.cpp,v 1.11 2008/09/20 01:53:18 bowkenken Exp $
+* $Id: WinPos.cpp,v 1.14 2009/03/13 14:54:38 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -101,6 +101,8 @@ void *WinPos::getWin( win_kind_t kind )
 		return gGuiReplay.mReplayWin;
 	case WIN_KIND_CLASS_EDIT:
 		return gGuiClassEdit.mClassEditWin;
+	case WIN_KIND_SKILL_EDIT:
+		return gGuiSkillEdit.mSkillEditWin;
 	case WIN_KIND_CHR_SHEET:
 		return gGuiChrSheet.mChrSheetWin;
 	case WIN_KIND_MAX_N:
@@ -273,6 +275,12 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 
 #ifdef D_MFC
 	if( flagDlg ){
+		CRect rect;
+		((CWnd *)pWin)->GetWindowRect( &rect );
+
+		w = rect.Width();
+		h = rect.Height();
+
 		if( (w > 0) && (h > 0) )
 			((CDialog *)pWin)->MoveWindow( x, y, w, h );
 	} else {
