@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.87 2008/09/19 21:15:24 bowkenken Exp $
+* $Id: call.cpp,v 1.100 2009/02/14 04:43:41 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -35,6 +35,14 @@
 extern WSCwindow *StatWin;
 #endif
 
+static long g_joy_n = 0;
+static joy_kind_t g_joy_kind = JOY_KIND_PS;
+
+static long g_win_x[WIN_KIND_MAX_N];
+static long g_win_y[WIN_KIND_MAX_N];
+static long g_win_w[WIN_KIND_MAX_N];
+static long g_win_h[WIN_KIND_MAX_N];
+
 /***************************************************************
 * GUI åɤΥå
 ***************************************************************/
@@ -258,7 +266,9 @@ void	call_gui_message_draw( void )
 * ϥɥ
 ***************************************************************/
 
-void	call_gui_num_draw( long *n, long min, long max, long figure )
+void	call_gui_num_draw(
+	volatile long *n, long min, long max, long figure
+)
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( !g_flg_init )
@@ -481,6 +491,7 @@ void	call_gui_replay_wipe( void )
 
 /***************************************************************
 * 饹ǥɥ
+* class_t *p : 饹
 ***************************************************************/
 
 void	call_gui_class_edit_draw( class_t *p )
@@ -519,6 +530,47 @@ void	call_gui_class_edit_wipe( void )
 #endif
 }
 
+/***************************************************************
+* 롦ǥɥ
+* class_t *p : 饹
+***************************************************************/
+
+void	call_gui_skill_edit_draw( class_t *p )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiSkillEdit.draw( p );
+
+	gui_end();
+#endif
+}
+
+/***************************************************************
+* 롦ǥɥĤ
+***************************************************************/
+
+void	call_gui_skill_edit_wipe( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gGuiSkillEdit.wipe();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * 饯ȡɥ
 ***************************************************************/
@@ -541,6 +593,8 @@ void	call_gui_chr_sheet_draw( mbr_t *org, mbr_t *mbr )
 
 /***************************************************************
 * 饯ȡɥ
+* mbr_t *org : Υ饯ǡ
+* mbr_t *mbr : ԽΥ饯ǡ
 ***************************************************************/
 
 void	call_gui_chr_sheet_redraw( mbr_t *org, mbr_t *mbr )
@@ -878,13 +932,31 @@ void	call_pcg_dun_draw(
 #endif // D_MFC
 }
 
+/***************************************************************
+* XX ιǡ
+* xx_act_kind_t kind : μ
+* void *p : Υǡ
+***************************************************************/
+
+void	call_pcg_dun_set_xx_attack(
+	long kind, void *p )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gPcgDun.setXxAttack( (xx_act_kind_t)kind, p );
+#endif
+}
+
 /***************************************************************
 * ƥȡ⡼ɤλޥåפʸ
 * long scrn_x : X ɸ
 * long scrn_y : Y ɸ
 * const char *s : եޥåʸ
 * ... : եޥåȤΰ
-* return : 顼̵ä
 ***************************************************************/
 
 void	call_pcg_dun_draw_string(
@@ -912,6 +984,32 @@ void	call_pcg_dun_draw_string(
 #endif
 }
 
+/***************************************************************
+* VFX 
+* long scrn_x : X ɸ
+* long scrn_y : Y ɸ
+* long scrn_w : 
+* long scrn_h : ⤵
+***************************************************************/
+
+void	call_pcg_dun_draw_vfx(
+	long scrn_x, long scrn_y,
+	long scrn_w, long scrn_h )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gPcgDun.drawVfx( scrn_x, scrn_y, scrn_w, scrn_h, false );
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ޥåפΥ
 * long map_x : ޥåפ X ɸ
@@ -1091,7 +1189,7 @@ bool_t	call_pcg_dun_clip_win( long mapX, long mapY )
 	return gPcgDun.clipWin( mapX, mapY );
 #endif
 
-	return true;
+	return TRUE;
 }
 
 /***************************************************************
@@ -1106,7 +1204,7 @@ bool_t	call_pcg_dun_clip_win_x( long mapX )
 	return gPcgDun.clipWinX( mapX );
 #endif
 
-	return true;
+	return TRUE;
 }
 
 /***************************************************************
@@ -1121,7 +1219,52 @@ bool_t	call_pcg_dun_clip_win_y( long mapY )
 	return gPcgDun.clipWinY( mapY );
 #endif
 
-	return true;
+	return TRUE;
+}
+
+/***************************************************************
+* 饹ܥΥǥ⤬äĴ٤
+* return : ǥ⤬ä?
+***************************************************************/
+
+void	call_demo_last_boss_reset( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	if( gPcgDun.pDemoLastBoss == NULL )
+		return;
+
+	gPcgDun.pDemoLastBoss->reset();
+#endif
+}
+
+/***************************************************************
+* 饹ܥΥǥ⤬äĴ٤
+* return : ǥ⤬ä?
+***************************************************************/
+
+bool_t	call_demo_last_boss_check_done( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return TRUE;
+	if( !g_flg_gui )
+		return TRUE;
+
+	if( gPcgDun.pDemoLastBoss == NULL )
+		return TRUE;
+
+	if( gPcgDun.pDemoLastBoss->checkDone() )
+		return TRUE;
+	else
+		return FALSE;
+#endif
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -1148,6 +1291,100 @@ void	call_game_music_play( long kind, long idx )
 #endif
 }
 
+/***************************************************************
+* BGM κƺ
+***************************************************************/
+
+void	call_game_music_replay( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gMusic.replay();
+#endif
+}
+
+/***************************************************************
+* SE κ
+* sound_kind_t kind : SE μ
+***************************************************************/
+
+void	call_game_sound_play( long kind, long n )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gSound.play( (sound_kind_t)kind, n );
+#endif
+}
+
+/***************************************************************
+* Υ祤ƥåֹ֤
+* return : 祤ƥåֹ
+***************************************************************/
+
+long	call_game_joystick_get_joy( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gJoystick.getJoy();
+#endif
+
+	return g_joy_n;
+}
+
+/***************************************************************
+* 祤ƥå
+* long n : 祤ƥåֹ
+***************************************************************/
+
+void	call_game_joystick_sel_joy( long n )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gJoystick.selJoy( n );
+#endif
+
+	g_joy_n = n;
+}
+
+/***************************************************************
+* 祤ƥå֤̾
+* long n : 祤ƥåֹ
+* return : 祤ƥå̾
+***************************************************************/
+
+const char	*call_game_joystick_get_name( long n )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gJoystick.getName( n );
+#endif
+
+	return NULL;
+}
+
+/***************************************************************
+* 祤ƥåμ֤
+* return : 祤ƥåμ
+***************************************************************/
+
+long	call_game_joystick_get_kind( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gJoystick.getKind();
+#endif
+
+	return g_joy_kind;
+}
+
+/***************************************************************
+* 祤ƥåμ
+* joy_kind_t kind : 祤ƥåμ
+***************************************************************/
+
+void	call_game_joystick_set_kind( long kind )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gJoystick.setKind( (joy_kind_t)kind );
+#endif
+
+	g_joy_kind = (joy_kind_t)kind;
+}
+
 /***************************************************************
 * ơɥ
 ***************************************************************/
@@ -1204,21 +1441,31 @@ void	call_win_pos_set(
 	long *pw, long *ph
 )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( k < WIN_KIND_NULL )
 		return;
 	if( k >= WIN_KIND_MAX_N )
 		return;
 
-	if( !g_flg_gui )
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( g_flg_gui ){
+		gui_begin();
+
+		gWinPos[k].set( k, px, py, pw, ph );
+
+		gui_end();
+
 		return;
-
-	gui_begin();
-
-	gWinPos[k].set( k, px, py, pw, ph );
-
-	gui_end();
+	}
 #endif
+
+	if( px != NULL )
+		g_win_x[k] = *px;
+	if( py != NULL )
+		g_win_y[k] = *py;
+	if( pw != NULL )
+		g_win_w[k] = *pw;
+	if( ph != NULL )
+		g_win_h[k] = *ph;
 }
 
 /***************************************************************
@@ -1237,25 +1484,40 @@ bool_t	call_win_pos_get(
 	long *pw, long *ph
 )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	if( k < WIN_KIND_NULL )
 		return FALSE;
 	if( k >= WIN_KIND_MAX_N )
 		return FALSE;
 
-	if( !g_flg_gui )
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( g_flg_gui ){
+		gui_begin();
+
+		gWinPos[k].get( k, px, py, pw, ph );
+
+		gui_end();
+
 		return TRUE;
-
-	gui_begin();
-
-	gWinPos[k].get( k, px, py, pw, ph );
-
-	gui_end();
-
-	return TRUE;
+	}
 #endif
 
-	return FALSE;
+	if( px != NULL )
+		*px = g_win_x[k];
+	if( py != NULL )
+		*py = g_win_y[k];
+	if( pw != NULL )
+		*pw = g_win_w[k];
+	if( ph != NULL )
+		*ph = g_win_h[k];
+
+	if( pw != NULL )
+		if( *pw <= 0 )
+			*pw = 256;
+	if( ph != NULL )
+		if( *ph <= 0 )
+			*ph = 256;
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -1285,6 +1547,26 @@ long	call_key_get_char( void )
 	return '\0';
 }
 
+/***************************************************************
+* 뤬ư˥ޥåפ򥹥뤹
+***************************************************************/
+
+void	call_key_check_move_crsr( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !g_flg_init )
+		return;
+	if( !g_flg_gui )
+		return;
+
+	gui_begin();
+
+	gKey.CheckMoveCrsr();
+
+	gui_end();
+#endif
+}
+
 /***************************************************************
 * ϤΥ
 * long n :  (ߥ)
