@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.113 2008/09/22 05:30:00 bowkenken Exp $
+* $Id: gmain.c,v 1.125 2009/03/10 12:46:14 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -180,6 +180,7 @@ void	init_game( void )
 	init_trap();
 	init_fx();
 	init_spell();
+	init_skill();
 	init_chr();
 	init_town();
 	init_menu();
@@ -188,6 +189,9 @@ void	init_game( void )
 	init_misc_menu();
 	init_main_menu();
 	init_request();
+	init_key_item();
+	init_last_boss();
+	init_ending();
 
 	init_mbr_formation();
 
@@ -244,6 +248,7 @@ void	reset_static( void )
 	reset_static_town();
 	reset_static_trap();
 	reset_static_turn();
+	reset_static_last_boss();
 
 #if	defined( D_GTK )
 #elif	defined( D_WS )
@@ -271,12 +276,15 @@ void	game_main( void )
 {
 	chk_scroll( TRUE );
 	redraw_all();
+	scroll_center_appear_party();
 
-	if( !g_flg_debug ){
+	if( g_flg_debug ){
+		menu_load_wiz();
+	} else {
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
 
-		menu_load_bar();
+		menu_load_start();
 
 		party_exit_bar();
 	}
@@ -299,6 +307,7 @@ void	game_over( void )
 		switch( get_key( FALSE ) ){
 		case CASE_EXIT:
 			exit_game( EXIT_SUCCESS );
+			break;
 		}
 	}
 }
@@ -309,12 +318,20 @@ void	game_over( void )
 
 void	ending( void )
 {
+	long	c;
+
 	change_scene( SCENE_N_ENDING );
 
 	while( 1 ){
-		switch( get_key( FALSE ) ){
-		case CASE_EXIT:
-			exit_game( EXIT_SUCCESS );
+		draw_ending();
+
+		c = get_key_no_wait();
+		if( c > 0 ){
+			switch( c ){
+			case CASE_EXIT:
+				exit_game( EXIT_SUCCESS );
+				break;
+			}
 		}
 	}
 }
@@ -369,11 +386,11 @@ void	chk_arg( int argc, char **argv )
 {
 	long	len;
 	long	mem_size;
-#if	(!HAVE_GETOPT && !HAVE_GETOPT_LONG)
+#if	!defined( HAVE_GETOPT ) && !defined( HAVE_GETOPT_LONG )
 	long	n = 0;
 	char	*optarg;
 	long	optind = argc;
-#endif	/* (!HAVE_GETOPT && !HAVE_GETOPT_LONG) */
+#endif	/* !defined( HAVE_GETOPT ) && !defined( HAVE_GETOPT_LONG ) */
 
 	if( argv == NULL )
 		return;
@@ -963,7 +980,7 @@ void	ena_term_unix( void )
 
 	flg_term++;
 
-#if	(HAVE_TERMIOS_H || HAVE_TERMIO_H)
+#if	defined( HAVE_TERMIOS_H ) || defined( HAVE_TERMIO_H )
 	if( flg_term == 1 ){
 		/* ¤Τ */
 # if	defined( HAVE_TERMIOS_H )
@@ -1009,7 +1026,7 @@ void	ena_term_unix( void )
 		}
 # endif	/* HAVE_TERMIOS_H */
 	}
-#endif	/* (HAVE_TERMIOS_H || HAVE_TERMIO_H) */
+#endif	/* defined( HAVE_TERMIOS_H ) || defined( HAVE_TERMIO_H ) */
 }
 
 /***************************************************************
@@ -1057,7 +1074,7 @@ void	clr_key_wait_unix( void )
 
 void	set_key_wait_vtime( long wait_vtime )
 {
-#if	(HAVE_TERMIOS_H || HAVE_TERMIO_H)
+#if	defined( HAVE_TERMIOS_H ) || defined( HAVE_TERMIO_H )
 	/* ¤Τ */
 # if	defined( HAVE_TERMIOS_H )
 	struct termios	tbuf;
@@ -1090,7 +1107,7 @@ void	set_key_wait_vtime( long wait_vtime )
 		exit_game( EXIT_FAILURE );
 	}
 # endif
-#endif	/* (HAVE_TERMIOS_H || HAVE_TERMIO_H) */
+#endif
 }
 
 /***************************************************************
