@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.58 2008/10/06 23:03:53 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.62 2009/01/04 00:26:03 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -97,7 +97,11 @@ int	main( int argc, char **argv )
 
 		gtk_main();
 
+		// λ
+
+		closeGameGui();
 		close_game( EXIT_SUCCESS );
+
 		gtk_exit( EXIT_SUCCESS );
 	} else {
 		// CUI Υᥤ󡦥롼פ򳫻
@@ -134,6 +138,7 @@ void	init_gtk_win( int argc, char **argv )
 	// SDL 
 
 	gMusic.init();
+	gSound.init();
 	gJoystick.init();
 
 	// ޡ
@@ -493,6 +498,16 @@ void	init_main_win( void )
 			MAP_WIN_MIN_HEIGHT() );
 }
 
+////////////////////////////////////////////////////////////////
+// ཪλν
+////////////////////////////////////////////////////////////////
+
+void	closeGameGui()
+{
+	gtk_timeout_remove( ghTimer );
+	gMusic.close();
+}
+
 ////////////////////////////////////////////////////////////////
 // ơС˥åɽ
 // const char *s : եޥåʸ
