@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.206 2008/04/18 23:05:34 bowkenken Exp $
+* $Id: menu.c,v 1.214 2009/03/11 10:51:24 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -289,33 +289,40 @@ void	init_ls_menu_func( void )
 			key = 'A';
 		}
 
-		sprintf( ls[k].path, "/func/%ld", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld", fn );
 		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
-		sprintf( ls[k].msg, MSG_MENU_FUNC_KEY, fn );
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_FUNC_KEY, fn );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/--", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/--", fn );
 		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
-		sprintf( ls[k].msg, MSG_MENU_FUNC_KEY, fn );
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_FUNC_KEY, fn );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/exec", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/exec", fn );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'X';
 		if( g_ls_func_short_key[fn].key == NULL ){
-			sprintf( ls[k].short_key, "&%02ld", fn );
+			sn_printf( ls[k].short_key, MENU_SHORT_KEY_MAX_LEN,
+					"&%02ld", fn );
 		} else {
-			sprintf( ls[k].short_key, "%s &%02ld",
+			sn_printf( ls[k].short_key, MENU_SHORT_KEY_MAX_LEN,
+					"%s &%02ld",
 					g_ls_func_short_key[i].key, fn );
 		}
 		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EXEC, MENU_MSG_MAX_LEN );
@@ -324,7 +331,8 @@ void	init_ls_menu_func( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/edit", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/edit", fn );
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'E';
 		ls[k].short_key[0] = '\0';
@@ -334,7 +342,8 @@ void	init_ls_menu_func( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/func/%ld/set reg macro", fn );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/func/%ld/set reg macro", fn );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'M';
 		ls[k].short_key[0] = '\0';
@@ -605,6 +614,16 @@ bool_t	set_menu_radio_item( menu_t *ls, menu_t *p )
 /**/
 
 ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel )
+{
+	if( ttl != NULL )
+		print_msg( FLG_NULL, MSG_S, ttl );
+
+	return exec_menu_ask_no_msg( ttl, dflt, can_cancel );
+}
+
+/**/
+
+ask_t	exec_menu_ask_no_msg( char *ttl, ask_t dflt, bool_t can_cancel )
 {
 	menu_t	*p;
 	char	*str_goto;
@@ -680,7 +699,7 @@ char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt )
 char	*exec_menu_sel_num( long *p, long min, long max )
 {
 	long	n;
-	long	gui_n;
+	volatile long	gui_n;
 	long	figure;
 	long	sel_n;
 	char	num[FIGURE_MAX_N];
@@ -706,17 +725,18 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 	sel_n = 1 + figure + MENU_NUM_OK;
 	while( 1 ){
 		long	d;
+		bool_t	flg_d;
 		bool_t	flg_ret;
 		char	key;
 
-		sprintf( num, fmt, (int)(figure + 1), n );
+		sn_printf( num, FIGURE_MAX_N, fmt, (int)(figure + 1), n );
 
 		draw_menu_num( figure, sel_n, num );
 
 		key = get_key_buf_char();
 		if( key == '\0' ){
 			if( g_flg_gui ){
-				call_gui_num_draw( &gui_n, min, max,
+				call_gui_num_draw( &n, min, max,
 						figure );
 			}
 
@@ -724,6 +744,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 		}
 
 		d = 0;
+		flg_d = FALSE;
 		flg_ret = FALSE;
 
 		switch( key ){
@@ -742,11 +763,17 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 				d = +1;
 			}
 			break;
+		case CASE_EXEC:
+			d = +-0;
+			flg_d = TRUE;
+			break;
 		case CASE_CRSR_UP:
 			d = +1;
+			flg_d = TRUE;
 			break;
 		case CASE_CRSR_DOWN:
 			d = -1;
+			flg_d = TRUE;
 			break;
 		case CASE_CRSR_LEFT:
 			sel_n--;
@@ -760,7 +787,6 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 				sel_n = 0;
 			break;
 		case '|':
-			n = gui_n;
 			break;
 		case KEY_MENU_NUM_OK:
 			sel_n = 1 + figure + MENU_NUM_OK;
@@ -783,7 +809,7 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 			break;
 		}
 
-		if( (d != 0) || flg_ret ){
+		if( flg_d || flg_ret ){
 			if( sel_n == 1 + figure + MENU_NUM_OK ){
 				if( flg_ret ){
 					if( n < min ){
@@ -816,7 +842,11 @@ char	*exec_menu_sel_num( long *p, long min, long max )
 			} else {
 				long	m;
 
-				m = num[sel_n] - '0' + d;
+				if( d == +-0 )
+					m = 0;
+				else
+					m = num[sel_n] - '0' + d;
+
 				if( m > 9 )
 					m = 0;
 				if( m < 0 )
@@ -1003,6 +1033,9 @@ menu_t	*sel_menu( menu_t *p, menu_t *dflt )
 		case '/':
 			return &dummy_menu_close_menu;
 			break;
+		case 'g':
+			exec_back_log();
+			break;
 		}
 
 		if( dy != +-0 ){
@@ -1371,7 +1404,7 @@ long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu )
 		}
 		break;
 
-#if	HAVE_LIBCURSES
+#ifdef	HAVE_LIBCURSES
 	case KEY_RESIZE:
 		redraw_all();
 		break;
@@ -1407,7 +1440,7 @@ long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu )
 	}
 
 	if( chk_redraw_every_turn() )
-		force_redraw_map();
+		force_clr_redraw_map();
 
 	if( g_flg_echo_key ){
 		if( (c != '\0') && (c != -1) ){
@@ -1489,12 +1522,12 @@ bool_t	chk_dup_short_key_main( menu_t *ls )
 bool_t	chk_dup_short_key_sub( unsigned char c, menu_t *ls )
 {
 	if( g_flg_dup_short_key[c] ){
-		char	s[8];
+		char	s[8 + 1];
 
 		if( ('A' - '@' <= c) && (c <= 'Z' - '@') )
-			sprintf( s, "^%c", c + '@' );
+			sn_printf( s, 8, "^%c", c + '@' );
 		else
-			sprintf( s, "%c", c );
+			sn_printf( s, 8, "%c", c );
 
 		print_err( MSG_ERR_MENU_SHORT_CUT_KEY,
 				s, MSG( ls->n_msg ) );
