@@ -52,6 +52,7 @@ void	garbage_collection_all_mnstr( void );
 void	mnstr_drop_gold( mnstr_t *p );
 void	mnstr_drop_bone( mnstr_t *p );
 void	mnstr_drop_item( mnstr_t *p );
+void	mnstr_drop_key_item( mnstr_t *p );
 void	set_find_all_mnstr( void );
 void	print_ls_mnstr( void );
 mnstr_kind_t	get_npc_kind_randm( void );
@@ -68,12 +69,6 @@ mnstr_tab_t	*get_towner_tab_rand( void );
 long	get_mnstr_lev_tab_max( void );
 mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev );
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p );
-void	exp_chr_mnstr(
-	chr_t *chr,
-	long exp,
-	bool_t flg_set_max,
-	bool_t flg_print_lev
-);
 long	calc_mnstr_exp( mnstr_t *p, long dun_lev );
 long	calc_mnstr_exp_sub( mnstr_t *p, long dun_lev );
 long	calc_mnstr_abl_lev( long dun_lev, abl_kind_t k, mnstr_tab_t *tab );
@@ -95,6 +90,7 @@ mnstr_t	*get_mnstr_randm( long x, long y );
 bool_t	already_mark_mnstr( mnstr_t *mnstr, mbr_t *mbr );
 mnstr_t	*get_mnstr_randm2( long x, long y );
 mnstr_kind_t	get_mnstr_kind_from_face( char mjr, char mnr );
+mnstr_t	*get_last_boss( last_boss_kind_t kind );
 mnstr_t	*get_mnstr_used( void );
 
 #ifdef __cplusplus
