@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.98 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: request.c,v 1.104 2009/03/04 08:12:53 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -81,6 +81,9 @@
 /* ¾ΰꥹȤ򸫤μ */
 #define	REQUEST_REFRESH_PRIZE	((gold_t)(1 * MBR_MAX_N))
 
+/* ̾ɽʸ */
+#define	REQUEST_NAME_MIN_LEN	14
+
 /***************************************************************
 * 󽷤ζȷиͤΨ
 ***************************************************************/
@@ -108,6 +111,21 @@
 
 #define	REQUEST_PENALTY_RATE	((rate_t)10)
 
+/***************************************************************
+* 󽷤Υƥ
+***************************************************************/
+
+scroll_kind_t	ls_reward_scroll[] = {
+	SCROLL_KIND_POW_UP_WPN_HIT,
+	SCROLL_KIND_POW_UP_WPN_CRTCL,
+	SCROLL_KIND_POW_UP_WPN_DAM,
+	SCROLL_KIND_POW_UP_ARMOR_DEF,
+	SCROLL_KIND_POW_UP_ARMOR_CRTCL,
+	SCROLL_KIND_POW_UP_ARMOR_AC,
+
+	SCROLL_KIND_NULL,
+};
+
 /***************************************************************
 * Хѿ
 ***************************************************************/
@@ -452,6 +470,8 @@ request_t	*make_request_exterminate( request_t *req )
 	tab = get_mnstr_tab_rand( -dun_lev );
 	if( tab == NULL )
 		return NULL;
+	if( tab->mnstr_kind == MNSTR_KIND_NULL )
+		return NULL;
 	lev_tab = get_mnstr_lev_tab( tab->mnstr_kind, dun_lev );
 	if( lev_tab == NULL )
 		return NULL;
@@ -714,8 +734,9 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	}
 
 	if( (msg_female != NULL) && (msg_male != NULL) ){
-		print_words( words_name, words_sex,
+		print_words_win( words_name, words_sex,
 				msg_female, msg_male, npc->name );
+		redraw_all();
 	}
 	print_msg( FLG_NULL, MSG_JOIN_CHR, npc->name );
 
@@ -1070,14 +1091,14 @@ bool_t	chk_request_limit_client( request_t *req )
 	case REQUEST_KIND_TAME_MNSTR:
 		return TRUE;	/* FALSE ǤϤʤ */
 	case REQUEST_KIND_RESCUE:
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				MSG_WORDS_REQUEST_RESCUE_LIMIT_FEMALE,
 				MSG_WORDS_REQUEST_RESCUE_LIMIT_MALE,
 				npc->name );
 		flg_trans_mnstr = TRUE;
 		break;
 	case REQUEST_KIND_TOUR_GUIDE:
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				MSG_WORDS_REQUEST_TOUR_GUIDE_LIMIT_FEMALE,
 				MSG_WORDS_REQUEST_TOUR_GUIDE_LIMIT_MALE,
 				npc->name );
@@ -1086,7 +1107,7 @@ bool_t	chk_request_limit_client( request_t *req )
 	case REQUEST_KIND_EXTERMINATE:
 		return FALSE;
 	case REQUEST_KIND_REVENGE:
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				MSG_WORDS_REQUEST_REVENGE_LIMIT_FEMALE,
 				MSG_WORDS_REQUEST_REVENGE_LIMIT_MALE,
 				npc->name );
@@ -1097,6 +1118,8 @@ bool_t	chk_request_limit_client( request_t *req )
 		return FALSE;
 	}
 
+	redraw_all();
+
 	/* ̤ */
 
 	print_msg( FLG_NULL, MSG_NOT_JOIN_CHR, npc->name );
@@ -1203,9 +1226,10 @@ void	chk_set_request_npc_contract( void )
 
 bool_t	set_request_msg( request_t *req )
 {
-	char	buf[REQUEST_MSG_MAX_LEN * 2], *fmt;
+	static char	buf[REQUEST_MSG_MAX_LEN + 1];
+	static char	str_contract[REQUEST_MSG_MAX_LEN + 1];
+	char	*fmt;
 	long	buf_idx, fmt_idx;
-	char	str_contract[REQUEST_MSG_MAX_LEN + 1];
 
 	if( req == NULL )
 		return FALSE;
@@ -1221,9 +1245,6 @@ bool_t	set_request_msg( request_t *req )
 			buf_idx--;
 		} else if( fmt[fmt_idx] & 0x80 ){
 			buf[buf_idx] = fmt[fmt_idx];
-			buf_idx++;
-			fmt_idx++;
-			buf[buf_idx] = fmt[fmt_idx];
 		} else if( fmt[fmt_idx] == '$' ){
 			if( fmt[fmt_idx + 1] == '$' ){
 				buf[buf_idx] = fmt[fmt_idx];
@@ -1250,7 +1271,7 @@ bool_t	set_request_msg( request_t *req )
 		else
 			name = cv_idx_to_contract_name( req );
 
-		sprintf( str_contract,
+		sn_printf( str_contract, REQUEST_MSG_MAX_LEN,
 				MSG_REQUEST_CONTRACT_FMT, name );
 	} else {
 		str_nz_cpy( str_contract,
@@ -1346,7 +1367,7 @@ void	set_request_msg_var_dun_min_lev(
 	if( req == NULL )
 		return;
 
-	sprintf( buf, "%ld", req->dun_min_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_min_lev );
 }
 
 /***************************************************************
@@ -1366,7 +1387,7 @@ void	set_request_msg_var_dun_max_lev(
 	if( req == NULL )
 		return;
 
-	sprintf( buf, "%ld", req->dun_max_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_max_lev );
 }
 
 /***************************************************************
@@ -1380,7 +1401,8 @@ void	set_request_msg_var_dun_lev_range(
 	request_t *req, char *buf, char *arg
 )
 {
-	char	str_min[32 + 1], str_max[32 + 1];
+	static char	str_min[32 * 4 + 1], str_max[32 * 4 + 1];
+	long	max_len = 32 * 4;
 
 	if( buf == NULL )
 		return;
@@ -1389,29 +1411,29 @@ void	set_request_msg_var_dun_lev_range(
 		return;
 
 	if( req->dun_min_lev >= +1 ){
-		sprintf( str_min, MSG_FLOOR_FMT,
+		sn_printf( str_min, max_len, MSG_FLOOR_FMT,
 				labs( req->dun_min_lev ) );
 	} else if( req->dun_min_lev <= -1 ){
-		sprintf( str_min, MSG_BASE_FMT,
+		sn_printf( str_min, max_len, MSG_BASE_FMT,
 				labs( req->dun_min_lev ) );
 	} else {
-		sprintf( str_min, MSG_S, MSG_GROUND );
+		sn_printf( str_min, max_len, MSG_S, MSG_GROUND );
 	}
 
 	if( req->dun_max_lev >= +1 ){
-		sprintf( str_max, MSG_FLOOR_FMT,
+		sn_printf( str_max, max_len, MSG_FLOOR_FMT,
 				labs( req->dun_max_lev ) );
 	} else if( req->dun_max_lev <= -1 ){
-		sprintf( str_max, MSG_BASE_FMT,
+		sn_printf( str_max, max_len, MSG_BASE_FMT,
 				labs( req->dun_max_lev ) );
 	} else {
-		sprintf( str_max, MSG_S, MSG_GROUND );
+		sn_printf( str_max, max_len, MSG_S, MSG_GROUND );
 	}
 
 	if( req->dun_min_lev == req->dun_max_lev ){
-		sprintf( buf, MSG_REQUEST_DUN_LEV, str_max );
+		sn_printf( buf, max_len, MSG_REQUEST_DUN_LEV, str_max );
 	} else {
-		sprintf( buf, MSG_REQUEST_DUN_LEV_RANGE,
+		sn_printf( buf, max_len, MSG_REQUEST_DUN_LEV_RANGE,
 				str_min, str_max );
 	}
 }
@@ -1470,7 +1492,8 @@ void	set_request_msg_var_rare_goods(
 	if( tab == NULL )
 		return;
 
-	sprintf( buf, MSG_REQUEST_VAR_QUOTE, tab->name );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			MSG_REQUEST_VAR_QUOTE, tab->name );
 }
 
 /***************************************************************
@@ -1505,10 +1528,12 @@ void	set_request_msg_var_mnstr(
 
 		tab = get_mnstr_tab( req->mnstr_kind, req->dun_true_lev );
 		if( tab == NULL ){
-			sprintf( buf, MSG_REQUEST_VAR_QUOTE,
+			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+					MSG_REQUEST_VAR_QUOTE,
 					MSG_MNSTR_UNKNOWN );
 		} else {
-			sprintf( buf, MSG_REQUEST_VAR_QUOTE,
+			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+					MSG_REQUEST_VAR_QUOTE,
 					tab->name );
 		}
 	}
@@ -1531,7 +1556,8 @@ void	set_request_msg_var_mnstr_n(
 	if( req == NULL )
 		return;
 
-	sprintf( buf, MSG_REQUEST_MNSTR_N, req->mnstr_n );
+	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			MSG_REQUEST_MNSTR_N, req->mnstr_n );
 }
 
 /***************************************************************
@@ -1749,10 +1775,12 @@ void	set_request_msg_var_ls(
 		*n_msg_idx = get_ls_n_msg_idx_randm( ls_msg );
 
 	if( flg_quote ){
-		sprintf( buf, MSG_REQUEST_VAR_QUOTE,
+		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+				MSG_REQUEST_VAR_QUOTE,
 				MSG( ls_msg[*n_msg_idx] ) );
 	} else {
-		sprintf( buf, MSG_S,
+		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+				MSG_S,
 				MSG( ls_msg[*n_msg_idx] ) );
 	}
 }
@@ -1766,6 +1794,8 @@ void	set_request_msg_var_ls(
 bool_t	set_request_heading( request_t *req )
 {
 	char	*str_contract;
+	char	*name;
+	long	len;
 
 	if( req == NULL )
 		return FALSE;
@@ -1782,9 +1812,14 @@ bool_t	set_request_heading( request_t *req )
 		str_contract = MSG_REQUEST_CONTRACT_STILL;
 	}
 
-	sprintf( req->heading, MSG_REQUEST_HEADING_FMT,
+	name = get_request_kind_name( req->kind );
+	len = get_pading_len( name, REQUEST_NAME_MIN_LEN );
+
+	sn_printf( req->heading, MENU_MSG_MAX_LEN,
+			MSG_REQUEST_HEADING_FMT,
 			str_contract,
-			get_request_kind_name( req->kind ),
+			len,
+			name,
 			req->dun_max_lev,
 			req->limit - get_game_day(),
 			fmt_gold( req->prize ) );
@@ -1880,13 +1915,15 @@ void	chk_find_request_chr( chr_t *chr )
 		msg_fema = MSG_WORDS_REQUEST_TAME_MNSTR_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_TAME_MNSTR_FIND_MALE;
 
-		print_words( mbr->name, mbr->sex.cur, msg_fema, msg_male );
+		print_words_win( mbr->name, mbr->sex.cur,
+				msg_fema, msg_male );
 		break;
 	case REQUEST_KIND_RESCUE:
 		msg_fema = MSG_WORDS_REQUEST_RESCUE_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_RESCUE_FIND_MALE;
 
-		print_words( mbr->name, mbr->sex.cur, msg_fema, msg_male );
+		print_words_win( mbr->name, mbr->sex.cur,
+				msg_fema, msg_male );
 		break;
 	case REQUEST_KIND_TOUR_GUIDE:
 		break;
@@ -1896,7 +1933,7 @@ void	chk_find_request_chr( chr_t *chr )
 		msg_fema = MSG_WORDS_REQUEST_REVENGE_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_REVENGE_FIND_MALE;
 
-		print_words( cv_idx_to_client_name( req ),
+		print_words_win( cv_idx_to_client_name( req ),
 				req->client_sex,
 				msg_fema,
 				msg_male,
@@ -1906,7 +1943,7 @@ void	chk_find_request_chr( chr_t *chr )
 		msg_fema = MSG_WORDS_REQUEST_WANTED_CRIMINAL_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_WANTED_CRIMINAL_FIND_MALE;
 
-		print_words( mbr->name, mbr->sex.cur,
+		print_words_win( mbr->name, mbr->sex.cur,
 				msg_fema,
 				msg_male,
 				cv_idx_to_mnstr_name( req ) );
@@ -1914,6 +1951,8 @@ void	chk_find_request_chr( chr_t *chr )
 	case REQUEST_KIND_MAX_N:
 		break;
 	}
+
+	redraw_all();
 }
 
 /***************************************************************
@@ -2153,9 +2192,10 @@ bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr )
 	if( cmp_chr( npc, chr ) )
 		return FALSE;
 
-	print_words( npc->name, npc->sex.cur,
+	print_words_win( npc->name, npc->sex.cur,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_MALE );
+	redraw_all();
 
 	finish_request( req );
 
@@ -2260,24 +2300,73 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
 
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_1_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_1_MALE );
 
 	add_party_gold( req->prize );
+	give_party_reward_item_randm();
 	exp_party( req->exp, FALSE, TRUE );
 
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_2_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_2_MALE );
 
 	/* end */
 
+	redraw_all();
+
 	req->kind = REQUEST_KIND_NULL;
 
 	return TRUE;
 }
 
+/***************************************************************
+* ʥƥ󽷤ȤƥѡƥͿ
+***************************************************************/
+
+void	give_party_reward_item_randm()
+{
+	scroll_kind_t	kind;
+	long	n;
+	long	tab_n;
+	item_t	*item;
+	long	i;
+
+	kind = SCROLL_KIND_NULL;
+	n = 0;
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( ls_reward_scroll[i] == SCROLL_KIND_NULL )
+			break;
+
+		n++;
+		if( per_randm( n ) )
+			kind = ls_reward_scroll[i];
+	}
+	if( kind == SCROLL_KIND_NULL )
+		return;
+
+	tab_n = get_scroll_tab_n( get_scroll_tab( kind ) );
+	item = make_item_scroll( -1, tab_n );
+	item->flg |= (FLG_ITEM_DETECTED | FLG_ITEM_IDENTIFIED);
+	item->flg &= ~(FLG_ITEM_CURSED);
+	set_item_name( item );
+
+	if( !give_party_reward_item( item ) )
+		del_item( item );
+}
+
+/***************************************************************
+* Υƥ󽷤ȤƥѡƥͿ
+* item_t *item : ƥ
+* return : Ϳ줿?
+***************************************************************/
+
+bool_t	give_party_reward_item( item_t *item )
+{
+	return give_party_item( item, TRUE, TRUE );
+}
+
 /***************************************************************
 * طƤΰ̤
 * request_t *req : 
@@ -2351,10 +2440,12 @@ void	not_join_client( request_t *req, pet_t *npc, bool_t flg_success )
 	}
 
 	if( flg_success && (msg_female != NULL) && (msg_male != NULL) ){
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				msg_female, msg_male );
 	}
 
+	redraw_all();
+
 	print_msg( FLG_NULL, MSG_NOT_JOIN_CHR, npc->name );
 	npc->gold = 0;
 	remove_pet( npc );
@@ -2616,7 +2707,7 @@ char	*set_menu_request(
 
 		set_request_heading( &(g_request[i]) );
 
-		sprintf( ls[k].path, "/request/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN, "/request/%ld", i );
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A'
@@ -2639,7 +2730,8 @@ char	*set_menu_request(
 			ls[k].accel_key = 'Z';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			sprintf( ls[k].msg, MSG_MENU_REQUEST_REFRESH,
+			sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+					MSG_MENU_REQUEST_REFRESH,
 					fmt_gold( REQUEST_REFRESH_PRIZE ) );
 			ls[k].call_back = cb_menu_request_refresh;
 			ls[k].arg = NULL;
@@ -2669,7 +2761,8 @@ char	*set_menu_request(
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		sprintf( ls[k].msg, MSG_MENU_REQUEST_REFRESH,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_REQUEST_REFRESH,
 				fmt_gold( REQUEST_REFRESH_PRIZE ) );
 		ls[k].call_back = cb_menu_request_refresh;
 		ls[k].arg = NULL;
@@ -2706,7 +2799,6 @@ char	*cb_menu_sel_request_mbr( menu_t **pp, menu_t **dflt )
 
 	set_request_msg( req );
 	draw_request( req );
-	wait_key( FALSE );
 
 	return STR_MENU_CANCEL;
 }
@@ -2729,7 +2821,6 @@ char	*cb_menu_sel_request_bar( menu_t **pp, menu_t **dflt )
 
 	set_request_msg( req );
 	draw_request( req );
-	wait_key( FALSE );
 
 	if( req->flg_finish )
 		return STR_MENU_CANCEL;
@@ -2812,7 +2903,7 @@ bool_t	ask_contract_request( request_t *req )
 
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
 			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
@@ -2838,7 +2929,9 @@ bool_t	ask_cancel_request( request_t *req )
 
 	penalty = req->prize * REQUEST_PENALTY_RATE / _100_PERCENT;
 
-	sprintf( msg, MSG_TTL_MENU_REQUEST_MBR_CANCEL, fmt_gold( penalty ) );
+	sn_printf( msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_REQUEST_MBR_CANCEL,
+			fmt_gold( penalty ) );
 	ask = exec_menu_ask( msg, ASK_NO, TRUE );
 	if( ask != ASK_YES )
 		return FALSE;
@@ -2854,7 +2947,7 @@ bool_t	ask_cancel_request( request_t *req )
 
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CANCEL_FEMALE,
 			MSG_WORDS_REQUEST_CANCEL_MALE );
 
